==> blink-components-0.4.0.tgz: package/.storybook/config.js <==
/* eslint-disable global-require */

import 'regenerator-runtime/runtime'
import { configure, setAddon } from '@kadira/storybook'
import infoAddon from '@storybook/addon-info'
import 'tachyons/css/tachyons.min.css'

setAddon(infoAddon)

function loadStories() {
  require('./connected/stories.js')
  require('./office/stories.js')
  require('./office2/stories.js')
  require('./realestate/stories.js')
  require('../components/PricingTable/stories.js')
  require('../components/Hero/stories.js')
  require('../components/HeroWithAction/stories.js')
  require('../components/Form/stories.js')
  require('../components/OptIn/stories.js')
  require('../components/ContactForm/stories.js')
  require('../components/FAQ/stories.js')
  require('../components/SocialShare/stories.js')
  require('../components/Section/stories.js')
  require('../components/SplitSection/stories.js')
  require('../components/Sections/stories.js')
  require('../components/CountUp/stories.js')
  require('../components/Stats/stories.js')
  require('../components/CustomerReviewList/stories.js')
  require('../components/Article/stories.js')
  require('../components/FlipCard/stories.js')
  require('../components/Navigation/stories.js')
  require('../components/Section/stories.js')
  require('../components/Example/stories.js')
  require('../components/Input/stories.js')
  require('../components/Button/stories.js')
  require('../components/GoogleMap/stories.js')
  require('../components/PostCard/stories.js')
  require('../components/Carousel/stories.js')
}

configure(loadStories, module)

==> blink-components-0.4.2.tgz: package/.storybook/config.js <==
/* eslint-disable global-require */

import 'regenerator-runtime/runtime'
import { configure, setAddon } from '@kadira/storybook'
import infoAddon from '@storybook/addon-info'
import 'tachyons/css/tachyons.min.css'

setAddon(infoAddon)

function loadStories() {
  require('./connected/stories.js')
  require('./office/stories.js')
  require('./office2/stories.js')
  require('./office3/stories.js')
  require('./realestate/stories.js')
  require('../components/PricingTable/stories.js')
  require('../components/Hero/stories.js')
  require('../components/HeroWithAction/stories.js')
  require('../components/Form/stories.js')
  require('../components/OptIn/stories.js')
  require('../components/LabelValue/stories.js')
  require('../components/ContactForm/stories.js')
  require('../components/FAQ/stories.js')
  require('../components/SimpleMap/stories.js')
  require('../components/SocialShare/stories.js')
  require('../components/Section/stories.js')
  require('../components/SplitSection/stories.js')
  require('../components/Sections/stories.js')
  require('../components/CountUp/stories.js')
  require('../components/Stats/stories.js')
  require('../components/CustomerReviewList/stories.js')
  require('../components/CustomerReviewGrid/stories.js')
  require('../components/Article/stories.js')
  require('../components/FlipCard/stories.js')
  require('../components/Navigation/stories.js')
  require('../components/Section/stories.js')
  require('../components/Example/stories.js')
  require('../components/Button/stories.js')
  require('../components/GoogleMap/stories.js')
  require('../components/PostCard/stories.js')
  require('../components/Carousel/stories.js')
}

configure(loadStories, module)
